package de.intevation.flys.artifacts;

import java.io.IOException;
import java.io.OutputStream;
import java.util.List;

import javax.xml.xpath.XPathConstants;

import org.w3c.dom.Document;

import org.apache.log4j.Logger;

import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.DefaultArtifact;
import de.intevation.artifactdatabase.state.State;
import de.intevation.artifactdatabase.state.StateEngine;

import de.intevation.flys.artifacts.context.FLYSContext;


/**
 * The default WINFO artifact.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class WINFOArtifact extends DefaultArtifact {

    /** The logger for this class */
    private static Logger logger = Logger.getLogger(WINFOArtifact.class);

    /** The name of the artifact. */
    public static final String ARTIFACT_NAME = "winfo";

    /** The XPath to the name of the artifact in its configuration. */
    public static final String XPATH_ARTIFACT_NAME = "@name";

    /** The current state. */
    protected State currentState;


    /**
     * The default constructor.
     */
    public WINFOArtifact() {
        super();
    }


    /**
     * Set the current state of this artifact.
     *
     * @param state The new current state.
     */
    protected void setCurrentState(State state) {
        currentState = state;
    }


    /**
     * Initialize the artifact and insert new data if <code>data</code> contains
     * information necessary for this artifact.
     *
     * @param identifier The UUID.
     * @param factory The factory that is used to create this artifact.
     * @param context The CallContext.
     * @param data Some optional data.
     */
    @Override
    public void setup(
        String          identifier,
        ArtifactFactory factory,
        Object          context,
        Document        data)
    {
        logger.debug("Setup this artifact with the uuid: " + identifier);

        super.setup(identifier, factory, context, data);

        FLYSContext flysContext = (FLYSContext) context;
        StateEngine engine      = (StateEngine) flysContext.get(
            FLYSContext.STATE_ENGINE_KEY);

        List<State> states = engine.getStates(ARTIFACT_NAME);

        setCurrentState(states.get(0));
    }


    /**
     * This method returns a description of this artifact.
     *
     * @param data Some data.
     * @param CallContext The CallContext.
     *
     * @return the description of this artifact.
     */
    public Document describe(Document data, CallContext context) {
        logger.debug("Describe the artifact.");
        logger.debug("The current state is: " + currentState.getID());

        return super.describe(data, context);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
